@@ -167,79 +167,6 @@ class AptSource(UpstreamSource):
         return True
 
 
-class DebianRulesSource(UpstreamSource):
-    """Upstream source that uses rules in debian/rules."""
-
-    def __init__(self, tree, top_level):
-        self.tree = tree
-        self.top_level = top_level
-
-    def _get_rule_source(self, source_dir, rule, make_vars=None):
-        command = ["make", "-f", "debian/rules", rule]
-        if make_vars is not None:
-            command.extend(["%s=%s" % item for item in make_vars.iteritems()])
-
-        proc = subprocess.Popen(command, cwd=source_dir)
-        ret = proc.wait()
-        if ret != 0:
-            note("Trying to run %s rule failed" % rule)
-            return False
-        return True
-
-    def _get_current_source(self, source_dir, package, version, target_dir):
-        rule = "get-packaged-orig-source"
-        note("Trying to use %s to retrieve needed tarball." % rule)
-        if not self._get_rule_source(source_dir, rule, {
-                "ORIG_VERSION": version,
-                "ORIG_PACKAGE": package}):
-            rule = "get-orig-source"
-            note("Trying to use %s to retrieve needed tarball (deprecated)." % rule)
-            if not self._get_rule_source(source_dir, rule):
-                return None
-        filenames = gather_orig_files(package, version, source_dir)
-        if not filenames:
-            note("%s did not create file for %s version %s", rule, package, version)
-            return None
-        if rule == "get-orig-source":
-            warning("Using get-orig-source to retrieve the packaged orig tarball "
-                    "is deprecated (see debian policy section 4.9). Provide the "
-                    "'get-packaged-orig-source' target instead.")
-        ret = []
-        for filename in filenames:
-            repack_tarball(
-                filename, os.path.basename(filename), target_dir=target_dir)
-            ret.append(os.path.join(target_dir, os.path.basename(filename)))
-        return ret
-
-    def _get_rules_id(self):
-        if self.top_level:
-            rules_name = 'rules'
-        else:
-            rules_name = 'debian/rules'
-        return self.tree.path2id(rules_name)
-
-    def fetch_tarballs(self, package, version, target_dir, components=None):
-        rules_id = self._get_rules_id()
-        if rules_id is None:
-            note("No debian/rules file to use to retrieve upstream tarball.")
-            raise PackageVersionNotPresent(package, version, self)
-        tmpdir = tempfile.mkdtemp(prefix="builddeb-get-source-")
-        try:
-            base_export_dir = os.path.join(tmpdir, "export")
-            export_dir = base_export_dir
-            if self.top_level:
-                os.mkdir(export_dir)
-                export_dir = os.path.join(export_dir, "debian")
-            export(self.tree, export_dir, format="dir")
-            tarball_paths = self._get_current_source(base_export_dir,
-                    package, version, target_dir)
-            if tarball_paths is None:
-                raise PackageVersionNotPresent(package, version, self)
-            return tarball_paths
-        finally:
-            shutil.rmtree(tmpdir)
-
-
 class UScanSource(UpstreamSource):
     """Upstream source that uses uscan."""
 
@@ -398,6 +325,8 @@ def gather_orig_files(package, version, path):
     if not os.path.isdir(path):
         return None
     for filename in os.listdir(path):
+        if filename.endswith('.asc'):
+            continue
         if filename.startswith(prefix):
             ret.append(os.path.join(path, filename))
     if ret:
